Name:           opengrm-ngram
Version:        1.0.3
Release:        2%{?dist}
Summary:        Library for making and modifying n-gram language models

License:        ASL 2.0
URL:            http://www.opengrm.org/
Source0:        http://www.openfst.org/twiki/pub/GRM/NGramDownload/%{name}-%{version}.tar.gz
# Man pages written by Jerry James.  The text of the man pages is lifted from
# the sources, so it is under the same copyright and license.  In short, I
# contributed the formatting, but none of the text.
Source1:        %{name}-man.tar.xz
# This patch will not be sent upstream, as it is gcc-specific.  Squelch
# warnings that may indicate miscompiled code.
Patch0:         %{name}-warning.patch
# Patch sent upstream 18 Dec 2012.  Get a missing prototype for getpid().
Patch1:         %{name}-getpid.patch

BuildRequires:  gsl-devel
BuildRequires:  openfst-devel
BuildRequires:  openfst-tools

%description
The OpenGrm NGram library is used for making and modifying n-gram
language models encoded as weighted finite-state transducers (FSTs).  It
makes use of functionality in the OpenFst library to create, access and
manipulate n-gram models.  Operations for counting, smoothing, pruning,
applying, and evaluating models are among those provided.

%package devel
Summary:        Development files for OpenGrm NGram
Group:          Development/Libraries
Requires:       %{name}%{?_isa} = %{version}-%{release}
Requires:       gsl-devel%{?_isa}, openfst-devel%{?_isa}

%description devel
This package includes the necessary files to develop systems with the
OpenGrm NGram library.

%package tools
Summary:        Command-line tools for working with n-gram language models
Group:          Applications/Multimedia
Requires:       %{name}%{?_isa} = %{version}-%{release}

%description tools
This package contains command-line tools that give access to OpenGrm
NGram library functionality.

%prep
%setup -q
%setup -q -T -D -a 1
%patch0
%patch1

%build
%configure CXXFLAGS="%{optflags} -DHAVE_GSL" LIBS="-lfst -lgsl"

# Get rid of undesirable hardcoded rpaths; also workaround libtool reordering
# -Wl,--as-needed after all the libraries.
sed -e 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' \
    -e 's|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' \
    -e 's|CC="g..|& -Wl,--as-needed|' \
    -i libtool

make %{?_smp_mflags}

%install
%make_install

# Remove libtool archives
rm -f %{buildroot}%{_libdir}/*.la

# Install the man pages
mkdir -p %{buildroot}%{_mandir}/man1
cd man
for f in *.1; do
  sed -e "s/@VERSION@/%{version}/" $f > %{buildroot}%{_mandir}/man1/$f
  touch -r $f %{buildroot}%{_mandir}/man1/$f
done
cd ..

%check
LD_LIBRARY_PATH=$PWD/src/lib/.libs make check

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files
%doc AUTHORS COPYING NEWS README
%{_libdir}/*.so.*

%files devel
%{_includedir}/ngram/
%{_libdir}/*.so

%files tools
%{_bindir}/*
%{_mandir}/man1/*

%changelog
* Wed Feb  6 2013 Jerry James <loganjerry@gmail.com> - 1.0.3-2
- Rebuild for openfst 1.3.3

* Tue Dec 18 2012 Jerry James <loganjerry@gmail.com> - 1.0.3-1
- Initial RPM
